@@ -29,12 +29,26 @@ except ImportError:
     lmhash, nthash = None, None
 from cl_print import color_print
 import cl_overriding
+from calculate.contrib.passlib.hash import sha256_crypt, grub_pbkdf2_sha512
 
 from calculate.lib.cl_lang import setLocalTranslate
 
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
+def get_shadow_hash():
+    """
+    Получить энкриптор для паролей unix
+    :return:
+    """
+    return sha256_crypt.using(rounds=5000, salt_size=8)
+
+def get_grub_hash():
+    """
+    Получить энкриптор для паролей grub
+    :return:
+    """
+    return grub_pbkdf2_sha512
 
 class encrypt(color_print):
     """Класс хранения общих методов используемых для настройки сервисов
