@@ -35,10 +35,6 @@ class samba(objShare):
     sepFields = "\n"
     reSepFields = re.compile(sepFields)
 
-    def __init__(self, text):
-        self.text = text
-        self.prepare()
-
     def prepare(self):
         self.blocTextObj = blocText()
         self._splitToFields = self.splitToFields
